@@ -3,11 +3,10 @@ name = "aidb"
 import os, sqlite3
 from datetime import datetime
 
-import appdirs # ToDo - can I delete this as it is only used in config?
 from peewee import *
 from playhouse.dataset import DataSet
 
-# Assumes that `pydatasci.create_config()` has been run during installation instructions:
+# Assumes `pds.create_config()` is run prior to `pds.get_config()`.
 from pydatasci import get_config
 
 
@@ -35,7 +34,7 @@ def get_path_dataset_ext():
 	if path is None:
 		print("\n Error - Cannot fetch database because it has not yet been configured.\n")
 	else:
-		# ToDo - test on windows... C:\\
+		# Despite looking weird, this path works on Windows: `sqlite:///C:\\...`
 		prefix = "sqlite:///"
 		prefix_db_path = prefix + path
 		return prefix_db_path
@@ -99,7 +98,7 @@ def delete_db(confirm:bool=False):
 		print("\n=> Warning - skipping deletion because `confirm` arg not set to boolean `True`.\n")
 
 
-# peewee ORM:
+# ============ ORM ============
 class BaseModel(Model):
     class Meta:
         database = get_db()
